@@ -3,8 +3,8 @@
  * Source: https://github.com/jeroen/curl
  * Comments and contributions are welcome!
  * Helpful libcurl examples:
- *  - http://curl.haxx.se/libcurl/c/getinmemory.html
- *  - http://curl.haxx.se/libcurl/c/multi-single.html
+ *  - https://curl.se/libcurl/c/getinmemory.html
+ *  - https://curl.se/libcurl/c/multi-single.html
  * Sparse documentation about Rconnection API:
  *  - https://github.com/wch/r-source/blob/trunk/src/include/R_ext/Connections.h
  *  - http://biostatmatt.com/R/R-conn-ints/C-Structures.html
@@ -27,6 +27,8 @@
 #elif (defined(__GLIBC__))
 #include <byteswap.h>
 #define BSWAP_32(x) bswap_32(x)
+#elif (defined(_AIX))
+#define BSWAP_32(x) __builtin_bswap32(x)
 #endif
 #endif
 
